part of tecfy_basic_package;

class AppTextFormField extends StatelessWidget {
  final TextInputAction? textInputAction;
  final TextEditingController? controller;
  final String Function(String?)? validator;
  final void Function()? onEditingComplete;
  final void Function(String)? onFieldSubmitted;
  final TextInputType? keyboardType;
  final String? labelText;
  final bool isRequired;
  final Widget? icon;
  final bool obscureText;
  final bool autoFocus;
  final int maxLines;
  final FocusNode? focusNode;
  final bool isDarkBackgound;
  final TextDirection? textDirection;
  final TextStyle? textStyle;
  AppTextFormField(
      {this.textInputAction,
      this.controller,
      this.isDarkBackgound = false,
      this.icon,
      this.textDirection,
      this.validator,
      this.keyboardType,
      this.labelText,
      this.isRequired = false,
      this.onEditingComplete,
      this.focusNode,
      this.obscureText = false,
      this.autoFocus = false,
      this.onFieldSubmitted,
      this.maxLines = 1,
      this.textStyle});

  TextStyle get defaultTextStyle => TextStyle(
      color: isDarkBackgound ? Colors.white : ThemeService.mainTextColor);

  @override
  Widget build(BuildContext context) {
    Widget result;
    if (maxLines > 1)
      result = getMultiRowText(context);
    else
      result = icon == null
          ? getSingleRowText(context)
          : Stack(children: <Widget>[
              getSingleRowText(context),
              Container(
                  height: 60,
                  padding: EdgeInsets.only(right: 10, left: 10),
                  child: Align(
                      child: icon,
                      alignment: ConfigService.isRTL
                          ? Alignment.centerLeft
                          : Alignment.centerRight))
            ]);

    return isDarkBackgound
        ? Theme(child: result, data: ThemeData.dark())
        : result;
  }

  Widget getSingleRowText(context) {
    return Theme.of(context).platform == TargetPlatform.iOS
        ? Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: <Widget>[
                Text(
                  '$labelText ${isRequired ? '*' : ''}',
                  style: TextStyle(
                      fontSize: 12.0,
                      color: isDarkBackgound ? Colors.white : Colors.black38),
                ),
                CupertinoTextField(
                    controller: controller,
                    textInputAction: textInputAction,
                    keyboardType: keyboardType,
                    //validator: validator,
                    onEditingComplete: onEditingComplete,
                    obscureText: obscureText,
                    maxLines: maxLines,
                    placeholder: labelText,
                    focusNode: focusNode,
                    autofocus: autoFocus,
                    onSubmitted: onFieldSubmitted,
                    style: textStyle ?? defaultTextStyle,
                    decoration: BoxDecoration()),
                Container(
                    height: 1.0,
                    color: isDarkBackgound ? Colors.white : Colors.black),
                SizedBox(height: 15.0)
              ])
        : TextFormField(
            textDirection: textDirection,
            enableInteractiveSelection: !obscureText,
            textInputAction: textInputAction,
            keyboardType: keyboardType,
            controller: controller,
            onEditingComplete: onEditingComplete,
            focusNode: focusNode,
            validator: validator,
            obscureText: obscureText,
            maxLines: maxLines,
            autofocus: autoFocus,
            style: textStyle ?? defaultTextStyle,
            onFieldSubmitted: onFieldSubmitted,
            enableSuggestions: true,
            decoration: InputDecoration(
              labelText: isRequired ? '$labelText*' : labelText,
              border: UnderlineInputBorder(),
            ),
          );
  }

  getMultiRowText(context) {
    return Theme.of(context).platform == TargetPlatform.iOS
        ? Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: <Widget>[
                Text('$labelText ${isRequired ? '*' : ''}',
                    style: TextStyle(fontSize: 12.0)),
                SizedBox(height: 5.9),
                Container(
                    height: 25.0 * maxLines,
                    decoration: ShapeDecoration(
                        shape: RoundedRectangleBorder(
                            borderRadius:
                                BorderRadius.all(Radius.circular(2.0)),
                            side: BorderSide(color: Colors.black38))),
                    child: Scrollbar(
                        child: SingleChildScrollView(
                            child: CupertinoTextField(
                                controller: controller,
                                onEditingComplete: onEditingComplete,
                                focusNode: focusNode,
                                textInputAction: textInputAction,
                                keyboardType: TextInputType.multiline,
                                obscureText: obscureText,
                                maxLines: 5,
                                placeholder: labelText,
                                style: textStyle ?? defaultTextStyle,
                                decoration: BoxDecoration()))))
              ])
        : TextFormField(
            textDirection: textDirection,
            enableInteractiveSelection: true,
            textInputAction: textInputAction,
            keyboardType: TextInputType.multiline,
            controller: controller,
            onEditingComplete: onEditingComplete,
            validator: validator,
            obscureText: obscureText,
            focusNode: focusNode,
            maxLines: maxLines,
            style: textStyle ?? defaultTextStyle,
            decoration: InputDecoration(
                labelText: isRequired ? '$labelText*' : labelText),
          );
  }
}
